/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.file;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;

/**
 * Unit test that tests that the header contains the absolute path to the filename it used.
 */
public class FileHeaderFileNameProducedTest extends ContextTestSupport {

    public void testHeaderFileNameProduced() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:result");
        mock.expectedMessageCount(1);
        // the absolute path to the file written should contain the target folder
        mock.message(0).header(Exchange.FILE_NAME_PRODUCED).contains("target");

        template.requestBodyAndHeader("direct:in", "Hello World", Exchange.FILE_NAME,
            "FileHeaderFileNameProducedTest.txt");

        mock.assertIsSatisfied();
    }


    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            public void configure() throws Exception {
                from("direct:in")
                    .to("file://target/?fileExist=Override")
                    .to("mock:result");
            }
        };
    }

}