/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.FailedToStartRouteException;
import org.apache.camel.builder.RouteBuilder;

/**
 * @version 
 */
public class RouteStartupOrderClashTest extends ContextTestSupport {

    @Override
    public boolean isUseRouteBuilder() {
        return false;
    }

    public void testRouteStartupOrderClash() throws Exception {
        context.addRoutes(new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("seda:foo").startupOrder(2).to("mock:result");

                from("direct:start").startupOrder(1).to("seda:foo");

                // clash as we got two routes with order 2
                from("seda:bar").startupOrder(2).to("mock:bar");
            }
        });

        try {
            context.start();
            fail("Should have thrown an exception");
        } catch (FailedToStartRouteException e) {
            // expected
            assertTrue(e.getMessage().contains("startupOrder 2"));
        }
    }

}