/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.processor.interceptor.DefaultTraceFormatter;
import org.apache.camel.processor.interceptor.Tracer;

public class TraceInterceptorWithOutBodyTraceTest extends TraceInterceptorTest {

    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            public void configure() throws Exception {
                // START SNIPPET: tracingOutExchanges
                Tracer tracer = new Tracer();
                tracer.setTraceOutExchanges(true);

                // we configure the default trace formatter where we can
                // specify which fields we want in the output
                DefaultTraceFormatter formatter = new DefaultTraceFormatter();
                formatter.setShowOutBody(true);
                formatter.setShowOutBodyType(true);

                // set to use our formatter
                tracer.setFormatter(formatter);
                
                getContext().addInterceptStrategy(tracer);
                // END SNIPPET: tracingOutExchanges
                
                from("direct:start").
                    transform().body().
                    to("mock:a").
                    to("mock:b");
            }
        };
    }

}
